# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.1] - 2021-12-07
### Fixed
- No changes, just bumping the patch number to avoid conflicts in TestPyPI

## [0.1.0] - 2021-12-07
### Added
- Linux support
- Generate LLDP frames with the three mandatory TLVs
- Specify how many frames to generate using the CLI
- Specify what network device to transmit on using the CLI
- Turn logging on/off using the CLI
- Support for probabilistic generation of LLDP frames
